@@ -161,6 +161,13 @@ class Microservices(BaseClass, ABC):
             port = os.environ.get('REDIS_PORT', 6379)
             self.redisclient = redis.Redis(
                 host=os.environ.get('REDISVALIDATE'), port=int(port), db=0)
+            if self.redisclient is None:
+                self.logs.warn(
+                    'No fue posible conectarse al servidor \
+                        de redis en la direccion: {}:{}'.format(
+                        os.environ.get('REDISVALIDATE'), int(port)
+                    ))
+                sys.exit(-1)
             self.logs.info('Se encuentra activado la validacion por redis')
 
     def hasProcessMessage(self, data):
